Lua_TrialPanel = class("Lua_TrialPanel", Lua_DisplayObject);
function Lua_TrialPanel:ctor(p)
	self:superCall("ctor", p, "TrialPanel_skin");
end

function Lua_TrialPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardBg:setLocation(0, 621 + self.adaptHeight / 2);
	self.rewardBg:SetDimensions(720, 758 + self.adaptHeight);

	self.taskList = Lua_DragList.new(self.content, 710, 730 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.taskList.tweenId = 2020;
	self.taskList.delayTween = true;
	self.taskList:setListCell(Lua_TrialEachItem, 710, 164, 1);
	self.taskList:setLocation(0, 265 + self.adaptHeight / 2, 0);
	self.taskList:setRectPivot(1);

	self.tips:addClickFuntion(self, self.onTipsBtnClick);

	self:addLuaEvent("UPDATE_TRIAL_TYPE_INFO", self, self.updateData);
end

function Lua_TrialPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.rewardBg:setLocation(0, 621 + adaptHeight / 2);
	self.rewardBg:SetDimensions(720, 758 + adaptHeight);
	self.taskList:setLocation(0, 265 + adaptHeight / 2, 0);
	self.taskList:setContentRect(710, 730 + adaptHeight);
end

function Lua_TrialPanel:setType(curShowType)
	self.taskList.showTween = true;
	self.selectType = curShowType;
	self.isFirst = true;
	self.infoBg:setUrl("/images/trial/ui_shilian_bj_00"..curShowType..".jpg");
end

function Lua_TrialPanel:updateData(updateShowType)
	if self.selectType ~= updateShowType then
		return;
	end

	local showIdx = DataCenter.TrialData:getTypeRecIndex(updateShowType);
	local data = DataCenter.TrialData:getTrialTypeById(updateShowType);
	self.taskList:setArrayData(data.script_arr);
	if self.isFirst then
		self.isFirst = false;
		self.taskList:moveToIndex(showIdx, true, false);
	end

	if data.free_times > 0 then
		self.freeTimesTxt.text = LanUtil.formateStr(200601, data.free_times);
	else
		self.freeTimesTxt.text = LanUtil.formateStr(200602, data.challenge_times);
	end
end

function Lua_TrialPanel:onTipsBtnClick(go)
	local tipData = { des = LanUtil.getValue(200611), posX = 190, posY = -535 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_TrialPanel:dispose()
	if self.taskList ~= nil then
		self.taskList:dispose();
		self.taskList = nil;
	end
	self:superCall("dispose")
end





--------------------------------------------------





Lua_TrialEachItem = class("Lua_TrialEachItem", Lua_ListCell);
function Lua_TrialEachItem:ctor(p)
	self:superCall("ctor", p, "TrialItem_skin");
end

function Lua_TrialEachItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rewardList = Lua_ItemIconList.new(self.content);
	self.rewardList:setLocation(-30, 0, 0);
	self.rewardList:setSiblingIndex(6);

	self.refreshBtn:addClickFuntion(self, self.onRefreshBtnClick);
end

function Lua_TrialEachItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.titleTxt.text = data.name;
	self.rewardList:setArrayData(data.reward);

	self.rightTopIcon:setEnable(DataCenter.TrialData.rec_Index == data.id);
	self.conditionTxt:setEnable(data.state == 0);
	self.mask:setEnable(data.state == 0);

	self.refreshBtn:setGray(data.state == 0);
	if data.state == 0 then -- 未开启
		self.refreshBtn:setLangValue(200603);

		local lightTowerVo = DataCenter.climbTowerData:getTowerVoById(Lua_ClimbTowerUtil.LIGHT_ID);
		if lightTowerVo ~= nil and lightTowerVo.cur_storey < data.stage_id then
			self.conditionTxt.text = LanUtil.formateStr(data.stage_name, tostring(data.stage_id));
		else
			self.conditionTxt.text = LanUtil.formateStr(data.level_name, tostring(data.level));
		end
	elseif data.state == 1 then -- 可挑战
		self.refreshBtn:setLangValue(200604);
	else -- 可扫荡
		local select_data = DataCenter.TrialData:getTrialTypeById(DataCenter.TrialData.curShowType);
		if select_data.free_times > 0 then -- 免费
			self.refreshBtn:setLangValue(200605);
		else
			if select_data.sweep_cost ~= nil then -- 消耗
				self.refreshBtn.label = spliceStr(spliceIconStrById(select_data.sweep_item), select_data.sweep_cost, LanUtil.getValue(200605));
			else
				self.refreshBtn:setLangValue(200605);
			end
		end
	end
end

function Lua_TrialEachItem:onPressClick()
	self.rewardList:onBoundClick();
end

function Lua_TrialEachItem:onRefreshBtnClick(go)
	if self.data.state == 0 then -- 未开启
		local str1 = "";
		local lightTowerVo = DataCenter.climbTowerData:getTowerVoById(Lua_ClimbTowerUtil.LIGHT_ID);
		if lightTowerVo ~= nil and self.data.stage_id > 0 then
			str1 = LanUtil.formateStr(200613, tostring(self.data.stage_id));
			str1 = str1 .. LanUtil.getValue(200614);
		end
		local str2 = LanUtil.formateStr(200615, tostring(self.data.level));
		OperateAlert.show(LanUtil.formateStr(200616, str1 .. str2));
	elseif self.data.state == 1 then -- 可挑战
		local minId = DataCenter.TrialData:getTypeMinId(DataCenter.TrialData.curShowType);
		if self.data.id > minId or minId == nil then
			OperateAlert.showLangValue(200606) -- 请先挑战上一难度
		else
			local select_data = DataCenter.TrialData:getTrialTypeById(DataCenter.TrialData.curShowType);
			local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(select_data.fight_id);
			DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onSceneShow, select_data.fight_id, sceneId, 0);
		end
	elseif self.data.state == 2 then -- 可扫荡
		local select_data = DataCenter.TrialData:getTrialTypeById(DataCenter.TrialData.curShowType);
		if select_data.free_times > 0 then
			Lua_ProxyManager.getProxy("Lua_TrialProxy"):sClear(self.data.id);
		else
			if select_data.sweep_cost == nil then
				OperateAlert.showLangValue(200617);
				return;
			end

			if DataCenter.roleData.vip > 0 then
				if select_data.challenge_times > 0 then -- 今日剩余购买挑战/扫荡次数
					if DataCenter.neverTipData:getNeverValue(Lua_NeverTipDefine.DAILY_TRIAL) then
						self:onChallengeFun();
					else
						local str = spliceIconStrById(Lua_ResourcesDefine.DIAMOND);
						local tipsData = {
							des = LanUtil.formateStr(200619, str, select_data.sweep_cost),
							btnType = 1,
							neverTip = Lua_NeverTipDefine.DAILY_TRIAL,
							owner = self,
							sureFun = self.onChallengeFun
						};
						Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
					end
				else
					if DataCenter.roleData.vip < select_data.buy_max_vip then
						OperateAlert.showLangValue(200607); -- 提升vip等级可增加购买次数
					else
						OperateAlert.showLangValue(200608); -- 次数不足
					end
				end
			else
				OperateAlert.showLangValue(200609);
			end
		end
	end
end

function Lua_TrialEachItem:onSceneShow(param, mp, success)
	if not success then return; end
	local data = Lua_LineupWinData.getData(param, self.data.monster_id, tonumber(self.data.id));
	Lua_WindowUtil.openWin("Lua_FightLineupWindow", Lua_WinParam.ACTION_OPEN, data);
end

function Lua_TrialEachItem:onChallengeFun()
	local select_data = DataCenter.TrialData:getTrialTypeById(DataCenter.TrialData.curShowType);
	if DataCenter.moneyData:isMoneyEnough(Lua_ResourcesDefine.DIAMOND, tonumber(select_data.sweep_cost), true, false, true) then
		OperateAlert.showLangValue(200618);
		Lua_ProxyManager.getProxy("Lua_TrialProxy"):sClear(self.data.id);
	end
end

function Lua_TrialEachItem:dispose()
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	self.data = nil;
	DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onSceneShow);

	self:superCall("dispose");
end